pub fn cargo_run_forward_args(forwarded: &[String]) -> Vec<String>Expand description
Build the cargo argv for forwarding a umbral <cmd> [args...]
invocation to the current project’s binary (cargo run -- <cmd> [args...]).
The global umbral scaffolding binary forwards every non-scaffolding
subcommand here so umbral dev behaves as cargo run -- dev. The
caller runs cargo with these args.